@@ -216,19 +216,16 @@ clock_timeout_callback (gpointer data)
 	if (!cd->showseconds &&
 	    cd->format != CLOCK_FORMAT_UNIX &&
 	    cd->format != CLOCK_FORMAT_CUSTOM) {
-		if (cd->format != CLOCK_FORMAT_INTERNET && 
-		    new_time % 60 != cd->current_time % 60)
-		{
-				update_clock (cd);
+		if (cd->format == CLOCK_FORMAT_INTERNET && 
+		    (long)get_itime (new_time) !=
+		    (long)get_itime (cd->current_time)) {
+			update_clock (cd);
+		} else if ((cd->format == CLOCK_FORMAT_12 ||
+			    cd->format == CLOCK_FORMAT_24) &&
+			   new_time / 60 != cd->current_time / 60) {
+			update_clock (cd);
 		}
-		else if ((long)get_itime (new_time) !=
-			 (long)get_itime (cd->current_time))
-		{
-				update_clock (cd);
-		}
-	}
-	else
-	{
+	} else {
 		update_clock (cd);
 	}
 
@@ -1617,7 +1614,7 @@ applet_change_background (PanelApplet               *applet,
 	gtk_widget_set_style (GTK_WIDGET (cd->applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (cd->applet), rc_style);
-	g_object_unref (rc_style);
+	gtk_rc_style_unref (rc_style);
 
 	switch (type) {
 	case PANEL_NO_BACKGROUND:
@@ -1632,6 +1629,7 @@ applet_change_background (PanelApplet               *applet,
 			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
 		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
 		gtk_widget_set_style (GTK_WIDGET (cd->applet), style);
+		g_object_unref (style);
 		break;
 	}
 }
@@ -2579,8 +2577,6 @@ display_about_dialog (BonoboUIComponent *uic,
 		"Dan Mueth <d-mueth@uchicago.edu>",
 		NULL
 	};
-	/* Translator credits */
-	const char *translator_credits = _("translator-credits");
 
 	if (cd->about) {
 		gtk_window_set_screen (GTK_WINDOW (cd->about),
@@ -2597,8 +2593,8 @@ display_about_dialog (BonoboUIComponent *uic,
 		      "comments", _("The Clock displays the current time and date"),
 		      "authors", authors,
 		      "documenters", documenters,
-		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-		      "logo_icon_name", "clock",
+		      "translator-credits", _("translator-credits"),
+		      "logo-icon-name", "clock",
 		      NULL);
 	
 	gtk_window_set_wmclass (GTK_WINDOW (cd->about), "clock", "Clock");
