@@ -477,8 +477,6 @@ display_about_dialog (BonoboUIComponent *uic,
 		"Sun GNOME Documentation Team <gdocteam@sun.com>",
           	NULL
 	};
-	/* Translator credits */
-	const char *translator_credits = _("translator-credits");
 
 	char        *authors [3];
 	char        *descr;
@@ -504,8 +502,8 @@ display_about_dialog (BonoboUIComponent *uic,
 		      "comments", descr,
 		      "authors", (const char **) authors,
 		      "documenters", documenters,
-		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-		      "logo_icon_name", "gnome-fish",
+		      "translator-credits", _("translator-credits"),
+		      "logo-icon-name", "gnome-fish",
 		      NULL);
 
 	g_free (descr);
@@ -1535,7 +1533,7 @@ fish_applet_change_background (PanelApplet               *panel_applet,
 	gtk_widget_set_style (GTK_WIDGET (applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-	g_object_unref (rc_style);
+	gtk_rc_style_unref (rc_style);
 
 	switch (type) {
 	case PANEL_NO_BACKGROUND:
@@ -1550,6 +1548,7 @@ fish_applet_change_background (PanelApplet               *panel_applet,
 			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
 		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
 		gtk_widget_set_style (GTK_WIDGET (applet), style);
+		g_object_unref (style);
 		break;
 	}
 }
