@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -643,6 +643,8 @@ egg_recent_model_monitor_list (EggRecentModel *model, GList *list)
 static gboolean
 egg_recent_model_changed_timeout (EggRecentModel *model)
 {
+	model->priv->changed_timeout = 0;
+
 	egg_recent_model_changed (model);
 
 	return FALSE;
@@ -929,6 +931,10 @@ egg_recent_model_finalize (GObject *object)
 {
 	EggRecentModel *model = EGG_RECENT_MODEL (object);
 
+	if (model->priv->changed_timeout > 0) {
+		g_source_remove (model->priv->changed_timeout);
+	}
+
 	egg_recent_model_monitor (model, FALSE);
 
 
@@ -1291,6 +1297,7 @@ egg_recent_model_add_full (EggRecentModel * model, EggRecentItem *item)
 		ret = TRUE;
 	} else {
 		g_warning ("Failed to lock:  %s", strerror (errno));
+		fclose (file);
 		return FALSE;
 	}
 
