@@ -33,7 +33,6 @@
 #include "panel.h"
 #include "drawer.h"
 #include "panel-applet-frame.h"
-#include "panel-stock-icons.h"
 #include "panel-action-button.h"
 #include "panel-menu-bar.h"
 #include "panel-toplevel.h"
@@ -84,9 +83,9 @@ typedef struct {
 	char                  *name;
 	char                  *description;
 	char                  *icon;
-	const char            *stock_icon;
 	PanelActionButtonType  action_type;
 	char                  *launcher_path;
+	char                  *menu_filename;
 	char                  *menu_path;
 	char                  *iid;
 	gboolean               static_data;
@@ -103,10 +102,10 @@ static PanelAddtoItemInfo special_addto_items [] = {
 	  N_("Custom Application Launcher"),
 	  N_("Create a new launcher"),
 	  "launcher-program",
-	  NULL,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
+	  NULL,
 	  "LAUNCHER:ASK",
 	  TRUE },
 
@@ -114,10 +113,10 @@ static PanelAddtoItemInfo special_addto_items [] = {
 	  N_("Application Launcher..."),
 	  N_("Launch a program that is already in the GNOME menu"),
 	  "launcher-program",
-	  NULL,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
+	  NULL,
 	  "LAUNCHER:MENU",
 	  TRUE }
 
@@ -128,33 +127,33 @@ static PanelAddtoItemInfo internal_addto_items [] = {
 	{ PANEL_ADDTO_MENU,
 	  N_("Main Menu"),
 	  N_("The main GNOME menu"),
-	  NULL,
-	  PANEL_STOCK_MAIN_MENU,
+	  PANEL_MAIN_MENU_ICON,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
+	  NULL,
 	  "MENU:MAIN",
 	  TRUE },
 
 	{ PANEL_ADDTO_MENUBAR,
 	  N_("Menu Bar"),
 	  N_("A custom menu bar"),
-	  NULL,
-	  PANEL_STOCK_GNOME_LOGO,
+	  PANEL_GNOME_LOGO_ICON,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
+	  NULL,
 	  "MENUBAR:NEW",
 	  TRUE },
 
 	{ PANEL_ADDTO_DRAWER,
 	  N_("Drawer"),
 	  N_("A pop out drawer to store other items in"),
-	  "drawer",
-	  NULL,
+	  PANEL_DRAWER_ICON,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
+	  NULL,
 	  "DRAWER:NEW",
 	  TRUE }
 };
@@ -221,7 +220,6 @@ panel_addto_prepend_internal_applets (GSList *list)
 		info->name        = (char *) panel_action_get_text (i);
 		info->description = (char *) panel_action_get_tooltip (i);
 		info->icon        = (char *) panel_action_get_icon_name (i);
-		info->stock_icon  = (char *) panel_action_get_stock_icon (i);
 		info->iid         = (char *) panel_action_get_drag_id (i);
 		info->static_data = TRUE;
 
@@ -255,7 +253,6 @@ static GdkPixbuf *
 panel_addto_make_pixbuf (const char *filename,
 			 GtkIconSize size)
 {
-	char *file;
 	GdkPixbuf *pb, *newpb;
 	int width, height;
 	int desired_width, desired_height;
@@ -263,14 +260,11 @@ panel_addto_make_pixbuf (const char *filename,
 	if (!gtk_icon_size_lookup (size, &desired_width, &desired_height))
 		return NULL;
 
-	file = gnome_desktop_item_find_icon (panel_icon_theme,
-					     filename, desired_height, 0);
-
-	if (file == NULL)
+	pb = panel_load_icon (gtk_icon_theme_get_default (), filename,
+			      desired_height, NULL);
+	if (!pb)
 		return NULL;
 
-	pb = gdk_pixbuf_new_from_file_at_size (file, desired_width,
-					       desired_height, NULL);
 	width = gdk_pixbuf_get_width (pb);
 	height = gdk_pixbuf_get_height (pb);
 
@@ -290,7 +284,6 @@ panel_addto_make_pixbuf (const char *filename,
 		pb = newpb;
 	}
 
-	g_free (file);
 	return pb;
 }
 
@@ -307,6 +300,30 @@ panel_addto_drag_data_get_cb (GtkWidget        *widget,
 				strlen (string));
 }
 
+static void
+panel_addto_drag_begin_cb (GtkWidget      *widget,
+			   GdkDragContext *context,
+			   gpointer        data)
+{
+	GtkTreeModel *model;
+	GtkTreePath  *path;
+	GtkTreeIter   iter;
+	GdkPixbuf    *pixbuf;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
+	   
+	gtk_tree_view_get_cursor (GTK_TREE_VIEW (widget), &path, NULL);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_path_free (path);
+
+	gtk_tree_model_get (model, &iter,
+	                    COLUMN_ICON, &pixbuf,
+	                    -1);
+
+	gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
+	g_object_unref (pixbuf);
+}
+
 static void
 panel_addto_setup_drag (GtkTreeView          *tree_view,
 			const GtkTargetEntry *target,
@@ -324,6 +341,9 @@ panel_addto_setup_drag (GtkTreeView          *tree_view,
 			       g_strdup (text),
 			       (GClosureNotify) g_free,
 			       0 /* connect_flags */);
+	g_signal_connect_after (G_OBJECT (tree_view), "drag-begin",
+	                        G_CALLBACK (panel_addto_drag_begin_cb),
+	                        NULL);
 }
 
 static void
@@ -452,14 +472,11 @@ panel_addto_append_item (PanelAddtoDialog *dialog,
 				    COLUMN_SEARCH, NULL,
 				    -1);
 	} else {
+		pixbuf = NULL;
+
 		if (applet->icon != NULL) {
 			pixbuf = panel_addto_make_pixbuf (applet->icon,
 							  GTK_ICON_SIZE_DIALOG);
-		} else {
-			pixbuf = gtk_widget_render_icon (GTK_WIDGET (dialog->panel_widget),
-							 applet->stock_icon,
-							 GTK_ICON_SIZE_DIALOG,
-							 NULL);
 		}
 
 		gtk_list_store_append (model, &iter);
@@ -473,6 +490,10 @@ panel_addto_append_item (PanelAddtoDialog *dialog,
 				    COLUMN_DATA, applet,
 				    COLUMN_SEARCH, applet->name,
 				    -1);
+
+		if (pixbuf)
+			g_object_unref (pixbuf);
+
 		g_free (text);
 	}
 }
@@ -530,7 +551,8 @@ panel_addto_make_applet_model (PanelAddtoDialog *dialog)
 
 static void
 panel_addto_make_application_list (GSList            **parent_list,
-				   MenuTreeDirectory  *directory)
+				   MenuTreeDirectory  *directory,
+				   const char         *filename)
 {
 	GSList *subdirs;
 	GSList *entries;
@@ -547,6 +569,7 @@ panel_addto_make_application_list (GSList            **parent_list,
 		data->item_info.name        = g_strdup (menu_tree_directory_get_name (subdir));
 		data->item_info.description = g_strdup (menu_tree_directory_get_comment (subdir));
 		data->item_info.icon        = g_strdup (menu_tree_directory_get_icon (subdir));
+		data->item_info.menu_filename = g_strdup (filename);
 		data->item_info.menu_path   = menu_tree_directory_make_path (subdir, NULL);
 		data->item_info.static_data = FALSE;
 
@@ -560,7 +583,8 @@ panel_addto_make_application_list (GSList            **parent_list,
 
 		*parent_list = g_slist_prepend (*parent_list, data);
 
-		panel_addto_make_application_list (&data->children, subdir);
+		panel_addto_make_application_list (&data->children, subdir,
+						   filename);
 
 		menu_tree_directory_unref (subdir);
 	}
@@ -615,9 +639,9 @@ panel_addto_populate_application_model (GtkTreeStore *store,
 				    COLUMN_SEARCH, data->item_info.name,
 				    -1);
 
-		if (pixbuf) {
+		if (pixbuf)
 			g_object_unref (pixbuf);
-		}
+
 		g_free (text);
 
 		if (data->children != NULL) 
@@ -643,7 +667,8 @@ panel_addto_make_application_model (PanelAddtoDialog *dialog)
 	tree = menu_tree_lookup ("applications.menu");
 
 	if ((root = menu_tree_get_root_directory (tree))) {
-		panel_addto_make_application_list (&dialog->application_list, root);
+		panel_addto_make_application_list (&dialog->application_list,
+						   root, "applications.menu");
 		panel_addto_populate_application_model (store, NULL, dialog->application_list);
 
 		menu_tree_directory_unref (root);
@@ -665,7 +690,7 @@ panel_addto_make_application_model (PanelAddtoDialog *dialog)
 				    -1);
 
 		panel_addto_make_application_list (&dialog->settings_list,
-						   root);
+						   root, "settings.menu");
 		panel_addto_populate_application_model (store, NULL,
 							dialog->settings_list);
 
@@ -714,6 +739,7 @@ panel_addto_add_item (PanelAddtoDialog   *dialog,
 	case PANEL_ADDTO_MENU:
 		panel_menu_button_create (dialog->panel_widget->toplevel,
 					  dialog->insertion_position,
+					  item_info->menu_filename,
 					  item_info->menu_path,
 					  item_info->menu_path != NULL,
 					  item_info->name);
@@ -744,7 +770,7 @@ panel_addto_dialog_response (GtkWidget *widget_dialog,
 	switch (response_id) {
 	case GTK_RESPONSE_HELP:
 		panel_show_help (gtk_window_get_screen (GTK_WINDOW (dialog->addto_dialog)),
-				 "user-guide.xml", "gospanel-28"); //FIXME
+				 "user-guide.xml", "gospanel-15");
 		break;
 
 	case PANEL_ADDTO_RESPONSE_ADD:
@@ -839,6 +865,10 @@ panel_addto_dialog_free_item_info (PanelAddtoItemInfo *item_info)
 		g_free (item_info->launcher_path);
 	item_info->launcher_path = NULL;
 
+	if (item_info->menu_filename != NULL)
+		g_free (item_info->menu_filename);
+	item_info->menu_filename = NULL;
+
 	if (item_info->menu_path != NULL)
 		g_free (item_info->menu_path);
 	item_info->menu_path = NULL;
@@ -894,6 +924,14 @@ panel_addto_dialog_free (PanelAddtoDialog *dialog)
 	panel_addto_dialog_free_application_list (dialog->application_list);
 	panel_addto_dialog_free_application_list (dialog->settings_list);
 
+	if (dialog->applet_model)
+		g_object_unref (dialog->applet_model);
+	dialog->applet_model = NULL;
+
+	if (dialog->application_model)
+		g_object_unref (dialog->application_model);
+	dialog->application_model = NULL;
+
 	if (dialog->menu_tree)
 		menu_tree_unref (dialog->menu_tree);
 	dialog->menu_tree = NULL;
@@ -1005,7 +1043,8 @@ panel_addto_selection_changed (GtkTreeSelection *selection,
 		case PANEL_ADDTO_MENU:
 			/* build the iid for menus other than the main menu */
 			if (data->iid == NULL) {
-				iid = g_strdup_printf ("MENU:%s",
+				iid = g_strdup_printf ("MENU:%s/%s",
+						       data->menu_filename,
 						       data->menu_path);
 			} else {
 				iid = g_strdup (data->iid);
