@@ -205,6 +205,7 @@ panel_properties_dialog_size_changed (PanelPropertiesDialog *dialog,
 					 gtk_spin_button_get_value_as_int (spin_button));
 }
 
+#define TOPLEVEL_MAX_SIZE 120
 static void
 panel_properties_dialog_setup_size_spin (PanelPropertiesDialog *dialog,
 					 GladeXML              *gui)
@@ -218,6 +219,10 @@ panel_properties_dialog_setup_size_spin (PanelPropertiesDialog *dialog,
 	dialog->size_label_pixels = glade_xml_get_widget (gui, "size_label_pixels");
 	g_return_if_fail (dialog->size_label_pixels != NULL);
 
+	gtk_spin_button_set_range (GTK_SPIN_BUTTON (dialog->size_spin),
+				   panel_toplevel_get_minimum_size (dialog->toplevel),
+				   TOPLEVEL_MAX_SIZE);
+
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->size_spin),
 				   panel_profile_get_toplevel_size (dialog->toplevel));
 
@@ -283,12 +288,13 @@ panel_properties_dialog_setup_icon_entry (PanelPropertiesDialog *dialog,
 		/* if the icon is not absolute path name it comes from the
 		   theme, and as such we wish to store the theme directory
 		   where it comes from.  See bug #119209 */
-		char *icon = gnome_desktop_item_find_icon (panel_icon_theme,
-							   custom_icon,
-							   48 /* FIXME: preffered_size */,
-							   0 /* flags */);
+		char *icon;
+		
+		icon = panel_find_icon (gtk_icon_theme_get_default (),
+					custom_icon, 48);
 		if (icon != NULL)
 			dialog->icon_theme_dir = g_path_get_dirname (icon);
+
 		g_free (custom_icon);
 		custom_icon = icon;
 	}
@@ -412,11 +418,14 @@ panel_properties_dialog_setup_image_chooser (PanelPropertiesDialog *dialog,
 
 	image = panel_profile_get_background_image (dialog->toplevel);
 
-	if (image) {
+	if (string_empty (image))
+		gtk_file_chooser_unselect_all (GTK_FILE_CHOOSER (dialog->image_chooser));
+	else
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog->image_chooser),
 					       image);
+	
+	if (image)
 		g_free (image);
-	}
 
 	g_signal_connect_swapped (dialog->image_chooser, "selection-changed",
 				  G_CALLBACK (panel_properties_dialog_image_changed),
@@ -764,11 +773,14 @@ panel_properties_dialog_update_background_image (PanelPropertiesDialog *dialog,
 	text = gconf_value_get_string (value);
 	old_text = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog->image_chooser));
 
-	if (text && (!old_text || strcmp (text, old_text)))
+	if (string_empty (text) && old_text)
+		gtk_file_chooser_unselect_all (GTK_FILE_CHOOSER (dialog->image_chooser));
+	else if (!string_empty (text) && (!old_text || strcmp (text, old_text)))
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog->image_chooser),
 					       text);
 
-	g_free (old_text);
+	if (old_text)
+		g_free (old_text);
 }
 
 static void
