@@ -13,7 +13,7 @@ typedef void (*UpdateFunction) (gpointer);
 
 #define		sure_string(s)		((const char *)((s)!=NULL?(s):""))
 
-int             panel_ditem_launch         (const GnomeDesktopItem       *item,
+int             panel_ditem_launch         (GnomeDesktopItem             *item,
 					    GList                        *file_list,
 					    GnomeDesktopItemLaunchFlags   flags,
 					    GdkScreen                    *screen,
@@ -37,6 +37,10 @@ GList *panel_g_list_resort_item   (GList        *list,
 				   gpointer      data,
 				   GCompareFunc  func);
 
+GSList *panel_g_slist_make_unique (GSList       *list,
+				   GCompareFunc  compare,
+				   gboolean      free_data);
+
 GtkWidget      *panel_error_dialog      (GdkScreen  *screen,
 					 const char *class,
 					 gboolean    auto_destroy,
@@ -56,6 +60,13 @@ gboolean	panel_uri_exists	(const char *uri);
 
 void            panel_lock_screen       (GdkScreen *screen);
 
+char *          panel_find_icon         (GtkIconTheme  *icon_theme,
+					 const char    *icon_name,
+					 gint           size);
+GdkPixbuf *     panel_load_icon         (GtkIconTheme  *icon_theme,
+					 const char    *icon_name,
+					 gint           size,
+					 char         **error_msg);
 GdkPixbuf *	missing_pixbuf		(int size);
 
 char *panel_make_full_path   (const char *dir,
